<?php
/**
 * Template Name: Contact Us Template                                            
 * The template for displaying contact us details.
 *
 * @link https://codex.wordpress.org/Template_Hierarchy
 *
 * @package Theme Palace
 * @subpackage Elead Pro
 * @since Elead Pro 1.0
 */

get_header(); 
$options = elead_pro_get_theme_options(); 
$contact_us_title      = ! empty( $options['contact_us_title'] ) ? $options['contact_us_title'] : '';
$contact_us_subtitle  = ! empty( $options['contact_us_subtitle'] ) ? $options['contact_us_subtitle'] : '';
$contact_us_address  = ! empty( $options['contact_us_address'] ) ? $options['contact_us_address'] : '';
$contact_us_phone  = ! empty( $options['contact_us_phone'] ) ? $options['contact_us_phone'] : '';
$contact_us_email  = ! empty( $options['contact_us_email'] ) ? $options['contact_us_email'] : '';

?>
<section id="contact-form">
    <div class="page-decoration align-center">
        <img src="<?php echo get_template_directory_uri() . '/assets/uploads/decoration.png'; ?>" alt="<?php esc_attr__( 'Decoration','elead-pro' ); ?>">
    </div><!-- .page-decoration -->
    <header class="entry-header align-center page-section no-padding-bottom">
        <div class="wrapper">
            <?php if ( ! empty( $contact_us_title ) ) : ?>
                <h2 class="entry-title"><?php echo esc_html( $contact_us_title ); ?></h2>
            <?php endif; 
            if ( ! empty( $contact_us_subtitle ) ) : ?>
                <p class="entry-title-desc"><?php echo esc_html( $contact_us_subtitle ); ?></p>
            <?php endif; ?>
        </div><!-- .wrapper -->
    </header><!-- .entry-header -->        
    
    <div class="entry-content">
        <div class="contact-information col-2">
            <div class="hentry">
                <div class="contact-details-wrapper page-section clear">
                    <i class="fa fa-map-marker"></i>
                    <h2 class="title"><?php esc_html_e( 'Contact', 'elead-pro' ); ?></h2>
                    <ul>
                        <?php if( ! empty ( $contact_us_address ) ) : ?>
                            <li class="address">
                               <label><?php esc_html_e( 'Address:', 'elead-pro' ); ?></label><span class="first"><?php echo esc_html( $contact_us_address ); ?></span>
                            </li>
                        <?php endif;
                        if( ! empty ( $contact_us_phone ) ) : ?>
                            <li class="phone">
                               <label><?php esc_html_e( 'Phone:', 'elead-pro' ); ?></label><span class="first"><a href="tel:<?php echo absint( preg_replace( '/\D+/', '', $contact_us_phone ) ); ?>"><?php echo esc_html( $contact_us_phone ); ?></a></span>
                            </li>
                        <?php endif;
                        if( ! empty ( $contact_us_email ) ) : ?>
                            <li class="email">
                               <label><?php esc_html_e( 'Email:', 'elead-pro' ); ?></label> <a href="mailto:<?php echo esc_attr( $contact_us_email ); ?>"><?php echo esc_html( $contact_us_email ); ?></a>
                            </li>
                        <?php endif; ?>
                    </ul>
                    <div class="widget widget_social_icons">
                        <ul class="social-icons">
                            <?php for ( $i = 1; $i <= 5; $i++ ) : 
                                $social_link = $options['contact_social_link_' . $i];
                                if ( ! empty( $social_link ) ) :
                                ?>
                                    <li><a href="<?php echo esc_url( $social_link ); ?>" target="_blank"></a></li>
                                <?php endif; 
                            endfor; ?>
                        </ul><!-- .social-icons -->
                    </div>
                </div><!-- .contact-details-wrapper -->
            </div><!-- .hentry -->
            <?php
            add_action( 'elead_pro_contact_map_action', 'elead_pro_contact_map', 10 );
            function elead_pro_contact_map() {
                $options = elead_pro_get_theme_options();
                if ( true === $options['contact_map_enable'] ) : 
                    $map_content_type       = ! empty( $options['map_content_type'] ) ? $options['map_content_type'] : '';
                    $map_content_embed      = ! empty( $options['map_content_embed'] ) ? $options['map_content_embed'] : '';
                    $map_content_shortcode  = ! empty( $options['map_content_shortcode'] ) ? $options['map_content_shortcode'] : '';

                    if ( 'shortcode' === $map_content_type ) {
                        if ( empty( $map_content_shortcode ) )
                            return false;
                    }
                    elseif ( 'embed' === $map_content_embed ) {
                        if ( empty( $map_content_embed ) )
                            return false;
                    }
                ?>
                    <div class="hentry">
                        <?php 
                        if ( $map_content_type == 'shortcode' ){
                            echo do_shortcode( wp_kses_post( $map_content_shortcode ) );
                        } elseif ( $map_content_type == 'embed'  ) {
                            echo elead_pro_santize_iframe_map( $map_content_embed );
                        }
                        ?>
                    </div>
                <?php endif;
            }
            /**
             * elead_pro_contact_map_action hook
             *
             * @hooked elead_pro_contact_map -  10
             *
             */
            do_action( 'elead_pro_contact_map_action' ); ?>
        </div><!-- .contact-information -->
    </div><!-- .entry-content -->
</section><!-- #contact-form -->

<?php if ( ! empty( $options['contact_page_form'] ) ) : ?>
    <section id="form" class="page-section">
        <div class="wrapper">
            <h2 class="form-title"><?php esc_html_e( 'Send us a Message', 'elead-pro' ); ?></h2>
            <?php echo do_shortcode( wp_kses_post( $options['contact_page_form'] ) ); ?>
        </div><!-- .wrapper -->
    </section><!-- #form -->
<?php endif;


get_footer();
