<?php 

/**
 * Service Template
 * Core service section
 *
 * This is the template for the content of core service section
 *
 * @package Theme Palace
 * @subpackage Elead Pro
 * @since Elead Pro 1.0
 */
if ( ! function_exists( 'elead_pro_add_core_service_section' ) ) :
    /**
    * Add core service section
    *
    *@since Elead Pro 1.0
    */
    function elead_pro_add_core_service_section() {
        $options = elead_pro_get_theme_options();

        // Check if core service is enabled
        $enable_core_service = $options['core_service_enable'];

        if ( true !== $enable_core_service ) {
            return false;
        }

        // Get core service section details
        $section_details = array();
        $section_details = apply_filters( 'elead_pro_filter_core_service_section_details', $section_details );
        if ( empty( $section_details ) ) {
            return;
        }
        // Render core service section now.
        elead_pro_render_core_service_section( $section_details );
    }
endif;
add_action( 'elead_pro_core_service_content', 'elead_pro_add_core_service_section', 10 );


if ( ! function_exists( 'elead_pro_get_core_service_section_details' ) ) :
    /**
    * core service section details.
    *
    * @since Elead Pro 1.0
    * @param array $input core service section details.
    */
    function elead_pro_get_core_service_section_details( $input ) {
        $options = elead_pro_get_theme_options();

        // core service type
        $core_service_content_type  = $options['core_service_content_type'];

        $content = array();
        switch ( $core_service_content_type ) {

            case 'post':
                $ids = array();
                
                if ( ! empty( $options['core_service_content_post'] ) )
                    $ids = ( array ) $options['core_service_content_post'];

                // Bail if no valid pages are selected.
                if ( empty( $ids ) ) {
                    return $input;
                }

                $args = array(
                    'no_found_rows'  => true,
                    'orderby'        => 'post__in',
                    'post_type'      => 'post',
                    'post__in'       => $ids,
                    'posts_per_page' => 4,
                );  
                
            break;

            case 'page':
                $ids = array();

                for ( $i = 1; $i <= 4; $i++ ) {
                    $id = null;
                    if ( isset( $options[ 'core_service_content_page_'.$i ] ) ) {
                        $id = $options[ 'core_service_content_page_'.$i ];
                    }
                    if ( ! empty( $id ) ) {
                        $ids[] = absint( $id );
                    }
                }

                // Bail if no valid pages are selected.
                if ( empty( $ids ) ) {
                    return $input;
                }

                $args = array(
                    'no_found_rows'  => true,
                    'orderby'        => 'post__in',
                    'post_type'      => 'page',
                    'post__in'       => $ids,
                );
            break;

            case 'custom':
                for ( $i = 1; $i <= 4; $i++ ) :

                    $content[$i]['title'] = ! empty( $options['core_service_custom_title_'.$i ] ) ? $options['core_service_custom_title_'.$i] : esc_html__( 'Easy Learning','elead-pro' );       
                    $content[$i]['excerpt'] = ! empty( $options['core_service_custom_excerpt_'.$i ] ) ? $options['core_service_custom_excerpt_'.$i] : esc_html__( 'Proin efficitur velit et cursus vulputate. Aenean ele mentum sodales libero vitae auctor. Pellentesque tellus nisl, porta eu feugiat et, eleifend ut mi','elead-pro' );
                    $content[$i]['url'] = ! empty( $options['core_service_custom_url_'.$i ] ) ? $options['core_service_custom_url_'.$i] : esc_html__( '#','elead-pro' );
                    $content[$i]['icon'] = ! empty( $options['core_service_custom_icon_'.$i ] ) ? $options['core_service_custom_icon_'.$i] : 'fa-bars';
                endfor;
            
            break;

        }
        if ( 'custom' != $core_service_content_type ) {
            $posts = get_posts( $args );
            if ( ! empty( $posts ) ) :
                $i = 1;
                foreach ( $posts as $post ) :
                    $post_id = $post->ID;
                    $icon = get_post_meta( $post_id, 'elead-pro-post-icon', true );
                    $content[$i]['id']       = $post_id;
                    $content[$i]['title']    = get_the_title( $post_id );
                    $content[$i]['url']      = get_the_permalink( $post_id );
                    $content[$i]['excerpt']  = elead_pro_trim_content( 20, $post );
                    $content[$i]['icon']     = ! empty( $icon ) ? $icon : 'fa-tint' ;
                    $i++;
                endforeach;
            endif;
        }

        if ( ! empty( $content ) ) {
            $input = $content;
        }
        return $input;
    }
endif;
// core service section content details.
add_filter( 'elead_pro_filter_core_service_section_details', 'elead_pro_get_core_service_section_details' );


if ( ! function_exists( 'elead_pro_render_core_service_section' ) ) :
    /**
    * Start core service section
    *
    * @return string core service content
    * @since Elead Pro 1.0
    *
    */
    function elead_pro_render_core_service_section( $content_details ) {
        $options = elead_pro_get_theme_options();
        $title = $options['core_service_title'] ? $options['core_service_title'] : '';
        $image  = $options['core_service_image'] ? $options['core_service_image'] :  get_template_directory_uri() . '/assets/uploads/core-service.jpg';
        
        if ( empty( $content_details ) ) {
            return;
        }

        $i = 1;
        ?>

        <section id="core-services" class="page-section">
            <div class="wrapper">
                <div class="services-context col-3 align-center">
                    <div class="hentry">
                        <?php foreach ( $content_details as $content_detail ) : ?>
                            <div class="service">
                                <?php if ( ! empty( $content_detail['icon'] ) ) : ?>
                                    <i class="fa <?php echo esc_attr( $content_detail['icon'] ); ?>"></i>
                                <?php endif;
                                if ( ! empty( $content_detail['title'] ) ) : ?>
                                <h5 class="featured-title"><a href="<?php echo ! empty( $content_detail['url'] ) ? esc_url( $content_detail['url'] ) : '#'; ?>"><?php echo esc_html( $content_detail['title'] ); ?></a></h5>
                                <?php endif; 
                                if ( ! empty( $content_detail['excerpt'] ) ) : ?>
                                    <p><?php echo esc_html( $content_detail['excerpt'] ); ?></p>
                                <?php endif; ?>
                            </div><!-- .service -->
                            <?php if ( $i == 2 ) : ?>
                                </div><!-- .hentry -->

                                <div class="hentry">
                                    <div class="featured-image" style="background-image:url('<?php echo esc_url( $image ); ?>')">
                                        <div class="black-overlay" style="opacity: 0.7;"></div>
                                        <?php if ( ! empty( $title ) ) :
                                        echo '<h5>' . esc_html( $title ) . '</h5>';
                                        endif; ?>
                                    </div><!-- .featured-image -->
                                </div><!-- .hentry -->

                                <div class="hentry">
                            <?php endif;
                            $i++; 
                        endforeach; ?>
                        
                    </div><!-- .hentry -->
                </div><!-- .entry-content -->
            </div><!-- .wrapper -->
        </section><!-- #core-services -->
       
    <?php }
endif;

/**
 * Service Template
 * Goal section
 *
 * This is the template for the content of goal section
 *
 * @package Theme Palace
 * @subpackage Elead Pro
 * @since Elead Pro 1.0
 */
if ( ! function_exists( 'elead_pro_add_service_goal_section' ) ) :
    /**
    * Add goal section
    *
    *@since Elead Pro 1.0
    */
    function elead_pro_add_service_goal_section() {
        $options = elead_pro_get_theme_options();

        // Check if core_service is enabled
        $enable_goal_section = $options['goal_section_enable'];

        if ( true !== $enable_goal_section ) {
            return false;
        }

        // Get goal section details
        $section_details = array();
        $section_details = apply_filters( 'elead_pro_filter_service_goal_section_details', $section_details );
        if ( empty( $section_details ) ) {
            return;
        }
        // Render goal section now.
        elead_pro_render_service_goal_section( $section_details );
    }
endif;
add_action( 'elead_pro_service_goal_content', 'elead_pro_add_service_goal_section', 10 );


if ( ! function_exists( 'elead_pro_get_service_goal_section_details' ) ) :
    /**
    * goal section details.
    *
    * @since Elead Pro 1.0
    * @param array $input goal section details.
    */
    function elead_pro_get_service_goal_section_details( $input ) {
        $options = elead_pro_get_theme_options();

        // service_goal type
        $service_goal_content_type  = $options['goal_content_type'];

        $content = array();

        switch ( $service_goal_content_type ) {

            case 'post':
                $ids = array();
                
                if ( ! empty( $options['goal_content_post'] ) )
                    $ids = ( array ) $options['goal_content_post'];

                // Bail if no valid pages are selected.
                if ( empty( $ids ) ) {
                    return $input;
                }

                $args = array(
                    'no_found_rows'  => true,
                    'orderby'        => 'post__in',
                    'post_type'      => 'post',
                    'post__in'       => $ids,
                    'posts_per_page' => 4,
                );  
                
          	break;

            case 'page':
                $ids = array();

                for ( $i = 1; $i <= 4; $i++ ) {
                    $id = null;
                    if ( isset( $options[ 'goal_content_page_'.$i ] ) ) {
                        $id = $options[ 'goal_content_page_'.$i ];
                    }
                    if ( ! empty( $id ) ) {
                        $ids[] = absint( $id );
                    }
                }

                // Bail if no valid pages are selected.
                if ( empty( $ids ) ) {
                    return $input;
                }

                $args = array(
                    'no_found_rows'  => true,
                    'orderby'        => 'post__in',
                    'post_type'      => 'page',
                    'post__in'       => $ids,
                );
            break;

            case 'custom':
                for ( $i = 1; $i <= 4; $i++ ) :

                    $content[$i]['title'] = ! empty( $options['goal_service_custom_title_'.$i ] ) ? $options['goal_service_custom_title_'.$i] : esc_html__( 'Quality Education','elead-pro' );       
                    $content[$i]['excerpt'] = ! empty( $options['goal_service_custom_excerpt_'.$i ] ) ? $options['goal_service_custom_excerpt_'.$i] : esc_html( 'Proin efficitur velit et cursus vulputate. Aenean ele mentum sodales libero vitae auctor. Pellentesque tellus nisl, porta eu feugiat et, eleifend ut mi.','elead-pro' );
                    $content[$i]['icon'] = ! empty( $options['goal_service_custom_icon_'.$i ] ) ? $options['goal_service_custom_icon_'.$i] : 'fa-cogs';
                endfor;
            break;    

        }
        if ( 'custom' != $service_goal_content_type ) {
            $posts = get_posts( $args );
            if ( ! empty( $posts ) ) :
                $i = 1;
                foreach ( $posts as $post ) :
                    $post_id = $post->ID;
                    $icon   = get_post_meta( $post_id, 'elead-pro-post-icon', true );
                    $content[$i]['id']       = $post_id;
                    $content[$i]['title']    = get_the_title( $post_id );
                    $content[$i]['excerpt']  = elead_pro_trim_content( 20, $post );
                    $content[$i]['icon']     = ! empty( $icon ) ? $icon : 'fa-tint' ;
                    $i++;
                endforeach;
            endif;
        }

        if ( ! empty( $content ) ) {
            $input = $content;
        }
        return $input;
    }
endif;
// goal section content details.
add_filter( 'elead_pro_filter_service_goal_section_details', 'elead_pro_get_service_goal_section_details' );


if ( ! function_exists( 'elead_pro_render_service_goal_section' ) ) :
    /**
    * Start goal section
    *
    * @return string goal content
    * @since Elead Pro 1.0
    *
    */
    function elead_pro_render_service_goal_section( $content_details ) {
        $options = elead_pro_get_theme_options();
        $title = $options['goal_service_title'] ? $options['goal_service_title'] : '';
        $image  = $options['goal_service_image'] ? $options['goal_service_image'] :  get_template_directory_uri() . '/assets/uploads/our-goal.jpg';
        
        if ( empty( $content_details ) ) {
            return;
        }
        ?>
        <section id="our-goal" class="col-2">
            <div class="page-decoration">
                <img src="<?php echo get_template_directory_uri() . '/assets/uploads/black.png'; ?>" alt="<?php esc_attr__( 'Black','elead-pro' ); ?>">
                <img src="<?php echo get_template_directory_uri() . '/assets/uploads/black.png'; ?>" alt="<?php esc_attr__( 'Black','elead-pro' ); ?>">
            </div>
            <div class="wrapper">
                <div class="align-center">
                    <div class="image-cover">
                    <img src="<?php echo get_template_directory_uri() . '/assets/uploads/ipad-cover.png'; ?>">
                        <div class="featured-image" style="background-image:url('<?php echo esc_url( $image ); ?>')">
                            <?php if ( ! empty( $title ) ) :
                                echo '<h2>' . esc_html( $title ) . '</h2>';
                            endif; ?>
                        </div><!-- .featured-image -->
                    </div><!-- .image-cover -->
                </div><!-- .align-center -->
                <div class="row page-section">
                <?php foreach ( $content_details as $content_detail ) : ?>
                    <div class="hentry">
                        <div class="services-guide">
                            <?php if ( ! empty( $content_detail['icon'] ) ) : ?>
                                <div class="icon-wrapper">
                                    <i class="fa <?php echo esc_attr( $content_detail['icon'] ); ?>"></i>
                                </div><!-- .icon-wrapper -->
                            <?php endif; ?>
                            <div class="services-goal">
                                <?php if ( ! empty( $content_detail['title'] ) ) : ?>
                                <h4><?php echo esc_html( $content_detail['title'] ); ?></h4>
                                <?php endif; 
                                if ( ! empty( $content_detail['excerpt'] ) ) : ?>
                                    <p><?php echo esc_html( $content_detail['excerpt'] ); ?></p>
                                <?php endif; ?>
                            </div><!-- .services-goal -->
                        </div><!-- .services-guide -->
                    </div><!-- .hentry -->
                <?php endforeach; ?>
                </div><!-- .row -->
            </div><!-- .wrapper -->
        </section><!-- .featured-goals -->
       
    <?php }
endif;


/**
 * Service Template
 * quality service section
 *
 * This is the template for the content of service section
 *
 * @package Theme Palace
 * @subpackage Elead Pro
 * @since Elead Pro 1.0
 */
if ( ! function_exists( 'elead_pro_add_quality_service_section' ) ) :
    /**
    * Add service section
    *
    *@since Elead Pro 1.0
    */
    function elead_pro_add_quality_service_section() {
        $options = elead_pro_get_theme_options();

        // Check if service is enabled
        $enable_quality_service = $options['quality_service_enable'];

        if ( true !== $enable_quality_service ) {
            return false;
        }

        // Get service section details
        $section_details = array();
        $section_details = apply_filters( 'elead_pro_filter_quality_service_section_details', $section_details );
        if ( empty( $section_details ) ) {
            return;
        }
        // Render service section now.
        elead_pro_render_quality_service_section( $section_details );
    }
endif;
add_action( 'elead_pro_quality_service_content', 'elead_pro_add_quality_service_section', 10 );


if ( ! function_exists( 'elead_pro_get_quality_service_section_details' ) ) :
    /**
    * service section details.
    *
    * @since Elead Pro 1.0
    * @param array $input service section details.
    */
    function elead_pro_get_quality_service_section_details( $input ) {
        $options = elead_pro_get_theme_options();

        // service type
        $quality_service_content_type  = $options['quality_service_content_type'];

        $content = array();
        switch ( $quality_service_content_type ) {

            case 'post':
                $ids = array();
                
                if ( ! empty( $options['quality_service_content_post'] ) )
                    $ids = ( array ) $options['quality_service_content_post'];

                // Bail if no valid pages are selected.
                if ( empty( $ids ) ) {
                    return $input;
                }

                $args = array(
                    'no_found_rows'  => true,
                    'orderby'        => 'post__in',
                    'post_type'      => 'post',
                    'post__in'       => $ids,
                    'posts_per_page' => 9,
                );  
                
            break;

            case 'category':
                $cat_id = '';
                if ( ! empty( $options['quality_service_content_category'] ) ) {
                    $cat_id = $options['quality_service_content_category'];
                }

                // Bail if no valid pages are selected.
                if ( empty( $cat_id ) ) {
                    return $input;
                }else{
                    $cat_id = absint( $cat_id );
                }

                $args = array(
                    'no_found_rows'  => true,
                    'cat'            => $cat_id,
                    'post_type'      => 'post',
                    'posts_per_page' => absint( $options['quality_service_count'] ),
                );
            break;

            case 'custom':
                for ( $i = 1; $i <= absint( $options['quality_service_count'] ); $i++ ) :

                    $content[$i]['title'] = ! empty( $options['quality_service_custom_title_'.$i ] ) ? $options['quality_service_custom_title_'.$i] : esc_html__( '24/7 Support','elead-pro' );       
                    $content[$i]['excerpt'] = ! empty( $options['quality_service_custom_excerpt_'.$i ] ) ? $options['quality_service_custom_excerpt_'.$i] : esc_html__( 'Proin efficitur velit et cursus vulputate. Aenean ele mentum sodales libero vitae auctor. Pellentesque tellus nisl, porta eu feugiat et, eleifend ut mi','elead-pro' );
                    $content[$i]['url'] = ! empty( $options['quality_service_custom_url_'.$i ] ) ? $options['quality_service_custom_url_'.$i] : esc_html__( '#','elead-pro' );
                    $content[$i]['icon'] = ! empty( $options['quality_service_custom_icon_'.$i ] ) ? $options['quality_service_custom_icon_'.$i] : 'fa-phone';
                endfor;
            
            break;

        }
        if ( 'custom' != $quality_service_content_type ) {
            $posts = get_posts( $args );
            if ( ! empty( $posts ) ) :
                $i = 1;
                foreach ( $posts as $post ) :
                    $post_id = $post->ID;
                    $content[$i]['icon']     = get_post_meta( $post_id, 'elead-pro-post-icon', true );
                    $content[$i]['title']    = get_the_title( $post_id );
                    $content[$i]['url']      = get_the_permalink( $post_id );
                    $content[$i]['excerpt']  = elead_pro_trim_content( 15, $post );
                    $i++;
                endforeach;
            endif;
        }

        if ( ! empty( $content ) ) {
            $input = $content;
        }
        return $input;
    }
endif;
// service section content details.
add_filter( 'elead_pro_filter_quality_service_section_details', 'elead_pro_get_quality_service_section_details' );


if ( ! function_exists( 'elead_pro_render_quality_service_section' ) ) :
    /**
    * Start service section
    *
    * @return string service content
    * @since Elead Pro 1.0
    *
    */
    function elead_pro_render_quality_service_section( $content_details ) {
        $options = elead_pro_get_theme_options();
        $title = $options['quality_service_title'] ? $options['quality_service_title'] : '';
        $sub_title = $options['quality_service_sub_title'] ? $options['quality_service_sub_title'] : '';
        
        if ( empty( $content_details ) ) {
            return;
        }
        ?>

        <section id="reasons" class="page-section" style="background-image: url('<?php echo get_template_directory_uri() . '/assets/uploads/promotion.jpg'; ?>'); background-position: 0% 9px;" data-stellar-background-ratio="0.5" data-stellar-vertical-offset="0">
            <div class="wrapper">
                <?php if ( ! empty( $title ) || ! empty( $sub_title ) ) : ?>
                    <header class="entry-header align-center">
                        <?php if ( ! empty( $title ) ) : ?>
                            <h2 class="entry-title"><?php echo esc_html( $title ); ?></h2>
                        <?php endif; 
                        if ( ! empty( $sub_title ) ) : ?>
                            <p class="entry-title-desc"><?php echo esc_html( $sub_title ); ?></p>
                        <?php endif; ?>
                    </header>
                <?php endif; ?>

                <div class="entry-content col-3">
                    <?php foreach ( $content_details as $content_detail ) : ?>
                        <div class="hentry">
                            <?php if ( ! empty( $content_detail['icon'] ) ) : ?>
                                <div class="icon">
                                    <a href="<?php echo ! empty( $content_detail['url'] ) ? esc_url( $content_detail['url'] ) : '#'; ?>">
                                        <i class="fa <?php echo esc_attr( $content_detail['icon'] ); ?>"></i>
                                    </a>
                                </div><!-- .icon -->
                            <?php endif; ?>
                            <div class="details">
                                <?php if ( ! empty( $content_detail['title'] ) ) : ?>
                                    <h5 class="featured-title">
                                        <a href="<?php echo ! empty( $content_detail['url'] ) ? esc_url( $content_detail['url'] ) : '#'; ?>">
                                            <?php echo esc_html( $content_detail['title'] ); ?>
                                        </a>
                                    </h5>
                                <?php endif;
                                if ( ! empty( $content_detail['excerpt'] ) ) : ?>
                                    <p><?php echo esc_html( $content_detail['excerpt'] ); ?></p>
                                <?php endif; ?>
                            </div><!-- .details -->
                        </div><!-- .hentry -->
                    <?php endforeach; ?>
                </div><!-- .entry-content -->
            </div><!-- .wrapper -->
        </section><!-- #reasons -->
       
    <?php }
endif;
