<?php
/**
 * Service Template options
 *
 * @package Theme Palace
 * @subpackage Elead Pro
 * @since Elead Pro 1.0
 */

// Add panel for Service Template
$wp_customize->add_panel( 'elead_pro_service_panel' , array(
    'title'      => esc_html__( 'Service Template','elead-pro' ),
    'description'=> esc_html__( 'Service Template Options', 'elead-pro' ),
    'priority'   => 150,
) );

/*
 * Core Service Section
 */
$wp_customize->add_section( 'elead_pro_core_service_section', array(
	'title'             => esc_html__( 'Core Service Section','elead-pro' ),
	'description'       => esc_html__( 'Core Service section options.', 'elead-pro' ),
	'panel'             => 'elead_pro_service_panel',
) );

// core service Section enable setting and control.
$wp_customize->add_setting( 'elead_pro_theme_options[core_service_enable]', array(
	'sanitize_callback'	=> 'elead_pro_sanitize_checkbox',
	'default'          	=> $options['core_service_enable'],
) );

$wp_customize->add_control( 'elead_pro_theme_options[core_service_enable]', array(
	'label'            	=> esc_html__( 'Enable Core Service', 'elead-pro' ),
	'section'          	=> 'elead_pro_core_service_section',
	'type'             	=> 'checkbox',
) );

// core service Section background image setting and control.
$wp_customize->add_setting( 'elead_pro_theme_options[core_service_image]', array(
	'default'           => $options['core_service_image'],
	'sanitize_callback' => 'elead_pro_sanitize_image'
) );

$wp_customize->add_control(
	new WP_Customize_Image_Control( $wp_customize, 'elead_pro_theme_options[core_service_image]',
		array(
		'label'       		=> esc_html__( 'Select Highlight Image', 'elead-pro' ),
		'description' 		=> sprintf( esc_html__( 'Recommended size: %1$dpx x %2$dpx ', 'elead-pro' ), 350, 710 ),
		'section'     		=> 'elead_pro_core_service_section',
		'active_callback'	=> 'elead_pro_is_core_service_enable',
) ) );

// core service Section title setting and control.
$wp_customize->add_setting( 'elead_pro_theme_options[core_service_title]', array(
	'sanitize_callback'	=> 'sanitize_text_field',
	'default'          	=> $options['core_service_title'],
) );

$wp_customize->add_control( 'elead_pro_theme_options[core_service_title]', array(
	'label'            	=> esc_html__( 'Title', 'elead-pro' ),
	'section'          	=> 'elead_pro_core_service_section',
	'type'             	=> 'text',
	'active_callback'	=> 'elead_pro_is_core_service_enable',
) );

// core service Section content type setting and control.
// options are same as goal section
$wp_customize->add_setting( 'elead_pro_theme_options[core_service_content_type]', array(
	'sanitize_callback'	=> 'elead_pro_sanitize_select',
	'default'			=> $options['core_service_content_type'],
) );

$wp_customize->add_control( 'elead_pro_theme_options[core_service_content_type]', array(
	'label'            	=> esc_html__( 'Core Services Content Type', 'elead-pro' ),
	'section'          	=> 'elead_pro_core_service_section',
	'type'             	=> 'select',
	'choices'			=> elead_pro_goal(),
	'active_callback'	=> 'elead_pro_is_core_service_enable',
) );

// core Section content type post setting and control.
$wp_customize->add_setting( 'elead_pro_theme_options[core_service_content_post]', array(
	'validate_callback' => 'elead_pro_validate_post_id',
	'sanitize_callback' => 'elead_pro_sanitize_post_ids',
) );

$wp_customize->add_control( 'elead_pro_theme_options[core_service_content_post]', array(
	'active_callback'	=> 'elead_pro_core_service_content_post',
	'label'             => esc_html__( 'Input Post Ids', 'elead-pro' ),
	'description'       => esc_html__( 'Please input 4 post ids. ie: 11, 24, 34', 'elead-pro' ),
	'section'           => 'elead_pro_core_service_section',
	'type'				=> 'text',
) );

for ( $i = 1; $i <= 4; $i++ ) {
	// core Section content type page setting and control
	// Show page drop-down setting and control
	$wp_customize->add_setting( 'elead_pro_theme_options[core_service_content_page_'.$i.']', array(
		'sanitize_callback' => 'elead_pro_sanitize_page'
	) );

	$wp_customize->add_control( 'elead_pro_theme_options[core_service_content_page_'.$i.']', array(
		'label'           	=> sprintf( esc_html__( 'Select Page %d', 'elead-pro' ), $i ),
		'section'        	=> 'elead_pro_core_service_section',
		'active_callback' 	=> 'elead_pro_core_service_content_page',
		'type'				=> 'dropdown-pages'
	) );

	// core section custom post hr setting and control
	$wp_customize->add_setting( 'elead_pro_theme_options[core_service_custom_hr_line_'.$i.']', array(
		'sanitize_callback' => 'sanitize_text_field'
	) );

	$wp_customize->add_control( new Elead_Pro_Customize_Horizontal_Line( $wp_customize, 'elead_pro_theme_options[core_service_custom_hr_line_'.$i.']',
		array(
			'section'         => 'elead_pro_core_service_section',
			'active_callback' => 'elead_pro_core_service_content_custom',
			'type'			  => 'hr'
	) ) );

	// core section custom note
	$wp_customize->add_setting( 'elead_pro_theme_options[core_service_custom_note_'.$i.']', array(
		'sanitize_callback'	=> 'sanitize_text_field',
	) );

	$wp_customize->add_control( new Elead_Pro_Note_Control( $wp_customize, 'elead_pro_theme_options[core_service_custom_note_'.$i.']', array(
		'label'           	=> sprintf( esc_html__( 'Input Custom Value For Core Service %s ', 'elead-pro' ),$i ),
		'section'         	=> 'elead_pro_core_service_section',
		'type'            	=> 'description',
		'active_callback' 	=> 'elead_pro_core_service_content_custom',
	) ) );

	// core section custom title setting and control.
	$wp_customize->add_setting( 'elead_pro_theme_options[core_service_custom_title_'.$i.']', array(
		'sanitize_callback' => 'sanitize_text_field',
		'default'			=> esc_html__( 'Easy Learning','elead-pro' ),
	) );

	$wp_customize->add_control( 'elead_pro_theme_options[core_service_custom_title_'.$i.']', array(
		'active_callback'	=> 'elead_pro_core_service_content_custom',
		'label'             => sprintf( esc_html__( 'Custom Title %s', 'elead-pro' ),$i ),
		'section'           => 'elead_pro_core_service_section',
		'type'				=> 'text'
	) );

	// core section custom title link setting and control.
	$wp_customize->add_setting( 'elead_pro_theme_options[core_service_custom_url_'.$i.']', array(
		'sanitize_callback' => 'esc_url_raw',
		'default'			=> esc_html__( '#','elead-pro' ),
	) );

	$wp_customize->add_control( 'elead_pro_theme_options[core_service_custom_url_'.$i.']', array(
		'active_callback'	=> 'elead_pro_core_service_content_custom',
		'label'             => sprintf( esc_html__( 'Custom Title Url %s', 'elead-pro' ),$i ),
		'section'           => 'elead_pro_core_service_section',
		'type'				=> 'url'
	) );

	// core section custom excerpt setting and control.
	$wp_customize->add_setting( 'elead_pro_theme_options[core_service_custom_excerpt_'.$i.']', array(
		'sanitize_callback' => 'wp_kses_post',
		'default'			=> esc_html__( 'Proin efficitur velit et cursus vulputate. Aenean ele mentum sodales libero vitae auctor. Pellentesque tellus nisl, porta eu feugiat et, eleifend ut mi.','elead-pro' ),
	) );

	$wp_customize->add_control( 'elead_pro_theme_options[core_service_custom_excerpt_'.$i.']', array(
		'active_callback'	=> 'elead_pro_core_service_content_custom',
		'label'             => sprintf( esc_html__( 'Custom Excerpt %s', 'elead-pro' ),$i ),
		'section'           => 'elead_pro_core_service_section',
		'type'				=> 'textarea'
	) );

	// core section custom icon setting and control.
	$wp_customize->add_setting( 'elead_pro_theme_options[core_service_custom_icon_'.$i.']', array(
		'sanitize_callback' => 'sanitize_text_field',
		'default'			=> 'fa-bars',
	) );

	$wp_customize->add_control( 'elead_pro_theme_options[core_service_custom_icon_'.$i.']', array(
		'active_callback'	=> 'elead_pro_core_service_content_custom',
		'label'             => sprintf( esc_html__( 'Custom Icon %s', 'elead-pro' ),$i ),
		'description'      => sprintf( esc_html__( 'Use font awesome icon: Eg: %1$s. %2$s See more here %3$s', 'elead-pro' ), 'fa-users', '<a href="' . esc_url( 'http://fontawesome.io/icons/' ) . '" target="_blank">', '</a>' ),
		'section'           => 'elead_pro_core_service_section',
		'type'				=> 'text'
	) );
}

/*
 * Goal Section
 */
$wp_customize->add_section( 'elead_pro_goal_section', array(
	'title'             => esc_html__( 'Goal Section','elead-pro' ),
	'description'       => esc_html__( 'Goal section options.', 'elead-pro' ),
	'panel'             => 'elead_pro_service_panel',
) );

// goal service Section enable setting and control.
$wp_customize->add_setting( 'elead_pro_theme_options[goal_section_enable]', array(
	'sanitize_callback'	=> 'elead_pro_sanitize_checkbox',
	'default'          	=> $options['goal_section_enable'],
) );

$wp_customize->add_control( 'elead_pro_theme_options[goal_section_enable]', array(
	'label'            	=> esc_html__( 'Enable Goal Section ', 'elead-pro' ),
	'section'          	=> 'elead_pro_goal_section',
	'type'             	=> 'checkbox',
) );


// Show title setting and control
$wp_customize->add_setting( 'elead_pro_theme_options[goal_service_title]', array(
	'default' 			=> $options['goal_service_title'],
	'sanitize_callback' => 'sanitize_text_field',
) );

$wp_customize->add_control( 'elead_pro_theme_options[goal_service_title]', array(
	'label'           	=> esc_html__( 'Title', 'elead-pro' ),
	'section'        	=> 'elead_pro_goal_section',
	'active_callback'	=> 'elead_pro_is_goal_section_enable',
	'type'				=> 'text'
) );

// goal service background image setting and control.
$wp_customize->add_setting( 'elead_pro_theme_options[goal_service_image]', array(
	'default'           => $options['goal_service_image'],
	'sanitize_callback' => 'elead_pro_sanitize_image'
) );

$wp_customize->add_control(
	new WP_Customize_Image_Control( $wp_customize, 'elead_pro_theme_options[goal_service_image]',
		array(
		'label'       		=> esc_html__( 'Select Highlight Image', 'elead-pro' ),
		'description' 		=> sprintf( esc_html__( 'Recommended size: %1$dpx x %2$dpx ', 'elead-pro' ), 550, 450 ),
		'section'     		=> 'elead_pro_goal_section',
		'active_callback'	=> 'elead_pro_is_goal_section_enable',
) ) );

// goal post hr setting and control
$wp_customize->add_setting( 'elead_pro_theme_options[goal_intro_hr]', array(
	'sanitize_callback' => 'sanitize_text_field'
) );

$wp_customize->add_control( new Elead_Pro_Customize_Horizontal_Line( $wp_customize, 'elead_pro_theme_options[goal_intro_hr]',
	array(
		'section'         => 'elead_pro_goal_section',
		'active_callback'   => 'elead_pro_is_goal_section_enable',
		'type'			  => 'hr'
) ) );

// goal section content type setting and control.
$wp_customize->add_setting( 'elead_pro_theme_options[goal_content_type]', array(
	'sanitize_callback'	=> 'elead_pro_sanitize_select',
	'default'			=> $options['goal_content_type'],
) );

$wp_customize->add_control( 'elead_pro_theme_options[goal_content_type]', array(
	'label'            	=> esc_html__( 'Goal Content Type', 'elead-pro' ),
	'description'       => esc_html__( 'Select content type to display goals.', 'elead-pro' ),
	'section'          	=> 'elead_pro_goal_section',
	'active_callback'   => 'elead_pro_is_goal_section_enable',
	'type'             	=> 'select',
	'choices'			=> elead_pro_goal(),
) );

// goal section content type post setting and control.
$wp_customize->add_setting( 'elead_pro_theme_options[goal_content_post]', array(
	'validate_callback' => 'elead_pro_validate_post_id',
	'sanitize_callback' => 'elead_pro_sanitize_post_ids',
) );

$wp_customize->add_control( 'elead_pro_theme_options[goal_content_post]', array(
	'active_callback'	=> 'elead_pro_service_goal_content_post',
	'label'             => esc_html__( 'Input Post Ids', 'elead-pro' ),
	'description'       => esc_html__( 'Please input 3 post ids. ie: 11, 24, 34', 'elead-pro' ),
	'section'           => 'elead_pro_goal_section',
	'type'				=> 'text',
) );

for ( $i = 1; $i <= 4; $i++ ) {
	// goal section content type page setting and control
	// Show page drop-down setting and control
	$wp_customize->add_setting( 'elead_pro_theme_options[goal_content_page_'.$i.']', array(
		'sanitize_callback' => 'elead_pro_sanitize_page'
	) );

	$wp_customize->add_control( 'elead_pro_theme_options[goal_content_page_'.$i.']', array(
		'label'           	=> sprintf( esc_html__( 'Select Page %d', 'elead-pro' ), $i ),
		'section'        	=> 'elead_pro_goal_section',
		'active_callback' 	=> 'elead_pro_service_goal_content_page',
		'type'				=> 'dropdown-pages'
	) );

	// goal section custom post hr setting and control
	$wp_customize->add_setting( 'elead_pro_theme_options[core_service_custom_hr_line_'.$i.']', array(
		'sanitize_callback' => 'sanitize_text_field'
	) );

	$wp_customize->add_control( new Elead_Pro_Customize_Horizontal_Line( $wp_customize, 'elead_pro_theme_options[goal_service_custom_hr_line_'.$i.']',
		array(
			'section'         => 'elead_pro_goal_section',
			'active_callback' => 'elead_pro_service_goal_content_custom',
			'type'			  => 'hr'
	) ) );

	// goal section custom note
	$wp_customize->add_setting( 'elead_pro_theme_options[goal_service_custom_note_'.$i.']', array(
		'sanitize_callback'	=> 'sanitize_text_field',
	) );

	$wp_customize->add_control( new Elead_Pro_Note_Control( $wp_customize, 'elead_pro_theme_options[goal_service_custom_note_'.$i.']', array(
		'label'           	=> sprintf( esc_html__( 'Input Custom Value For Goal Service %s ', 'elead-pro' ),$i ),
		'section'         	=> 'elead_pro_goal_section',
		'type'            	=> 'description',
		'active_callback' 	=> 'elead_pro_service_goal_content_custom',
	) ) );

	// goal section custom title setting and control.
	$wp_customize->add_setting( 'elead_pro_theme_options[goal_service_custom_title_'.$i.']', array(
		'sanitize_callback' => 'sanitize_text_field',
		'default'				=> esc_html__( 'Quality Education','elead-pro' ),
	) );

	$wp_customize->add_control( 'elead_pro_theme_options[goal_service_custom_title_'.$i.']', array(
		'active_callback'	=> 'elead_pro_service_goal_content_custom',
		'label'             => sprintf( esc_html__( 'Custom Title %s', 'elead-pro' ),$i ),
		'section'           => 'elead_pro_goal_section',
		'type'				=> 'text'
	) );

	// goal section custom excerpt setting and control.
	$wp_customize->add_setting( 'elead_pro_theme_options[goal_service_custom_excerpt_'.$i.']', array(
		'sanitize_callback' => 'wp_kses_post',
		'default'				=> esc_html__( 'Proin efficitur velit et cursus vulputate. Aenean ele mentum sodales libero vitae auctor. Pellentesque tellus nisl, porta eu feugiat et, eleifend ut mi.','elead-pro' ),
	) );

	$wp_customize->add_control( 'elead_pro_theme_options[goal_service_custom_excerpt_'.$i.']', array(
		'active_callback'	=> 'elead_pro_service_goal_content_custom',
		'label'             => sprintf( esc_html__( 'Custom Excerpt %s', 'elead-pro' ),$i ),
		'section'           => 'elead_pro_goal_section',
		'type'				=> 'textarea'
	) );

	// goal section custom icon setting and control.
	$wp_customize->add_setting( 'elead_pro_theme_options[goal_service_custom_icon_'.$i.']', array(
		'sanitize_callback' => 'sanitize_text_field',
		'default'			=> 'fa-cogs',
	) );

	$wp_customize->add_control( 'elead_pro_theme_options[goal_service_custom_icon_'.$i.']', array(
		'active_callback'	=> 'elead_pro_service_goal_content_custom',
		'label'             => sprintf( esc_html__( 'Custom Icon %s', 'elead-pro' ),$i ),
		'description'      => sprintf( esc_html__( 'Use font awesome icon: Eg: %1$s. %2$s See more here %3$s', 'elead-pro' ), 'fa-users', '<a href="' . esc_url( 'http://fontawesome.io/icons/' ) . '" target="_blank">', '</a>' ),
		'section'           => 'elead_pro_goal_section',
		'type'				=> 'text'
	) );
}

/*
 * Quality Service Section
 */
$wp_customize->add_section( 'elead_pro_quality_service_section', array(
	'title'             => esc_html__( 'Quality Service Section','elead-pro' ),
	'description'       => esc_html__( 'Quality Service section options.', 'elead-pro' ),
	'panel'             => 'elead_pro_service_panel',
) );

// Quality service section enable setting and control.
$wp_customize->add_setting( 'elead_pro_theme_options[quality_service_enable]', array(
	'sanitize_callback'	=> 'elead_pro_sanitize_checkbox',
	'default'          	=> $options['quality_service_enable'],
) );

$wp_customize->add_control( 'elead_pro_theme_options[quality_service_enable]', array(
	'label'            	=> esc_html__( 'Enable Quality Service', 'elead-pro' ),
	'section'          	=> 'elead_pro_quality_service_section',
	'type'             	=> 'checkbox',
) );

// quality service section title setting and control.
$wp_customize->add_setting( 'elead_pro_theme_options[quality_service_title]', array(
	'sanitize_callback'	=> 'sanitize_text_field',
	'default'          	=> $options['quality_service_title'],
) );

$wp_customize->add_control( 'elead_pro_theme_options[quality_service_title]', array(
	'label'            	=> esc_html__( 'Title', 'elead-pro' ),
	'section'          	=> 'elead_pro_quality_service_section',
	'type'             	=> 'text',
	'active_callback'	=> 'elead_pro_is_quality_service_enable',
) );

// quality service section sub title setting and control.
$wp_customize->add_setting( 'elead_pro_theme_options[quality_service_sub_title]', array(
	'sanitize_callback'	=> 'sanitize_text_field',
	'default'          	=> $options['quality_service_sub_title'],
) );

$wp_customize->add_control( 'elead_pro_theme_options[quality_service_sub_title]', array(
	'label'            	=> esc_html__( 'Sub Title', 'elead-pro' ),
	'section'          	=> 'elead_pro_quality_service_section',
	'type'             	=> 'text',
	'active_callback'	=> 'elead_pro_is_quality_service_enable',
) );

// quality service section content type setting and control.
$wp_customize->add_setting( 'elead_pro_theme_options[quality_service_content_type]', array(
	'sanitize_callback'	=> 'elead_pro_sanitize_select',
	'default'			=> $options['quality_service_content_type'],
) );

$wp_customize->add_control( 'elead_pro_theme_options[quality_service_content_type]', array(
	'label'            	=> esc_html__( 'Quality Services Content Type', 'elead-pro' ),
	'section'          	=> 'elead_pro_quality_service_section',
	'type'             	=> 'select',
	'choices'			=> elead_pro_quality_service(),
	'active_callback'	=> 'elead_pro_is_quality_service_enable',
) );

// Quality service count setting and control.
$wp_customize->add_setting( 'elead_pro_theme_options[quality_service_count]', array(
	'default'           => $options['quality_service_count'],
	'sanitize_callback' => 'elead_pro_sanitize_number_range',
	'validate_callback' => 'elead_pro_validate_quality_service_count',
	'transport'			=> 'postMessage',
) );

$wp_customize->add_control( 'elead_pro_theme_options[quality_service_count]', array(
	'label'           	=> esc_html__( 'Number of Quality Services', 'elead-pro' ),
	'description'       => esc_html__( 'Note: Min 3 & Max 9. Please input the valid number and save. Then refresh the page to see the change.', 'elead-pro' ),
	'section'         	=> 'elead_pro_quality_service_section',
	'type'            	=> 'number',
	'active_callback' 	=> 'elead_pro_quality_service_content_not_post',
	'input_attrs'     	=> array(
		'max' 	=> 9,
		'min' 	=> 3,
		'style' => 'width:100px'
	)
) );

// Quality Section content type category setting and control
$wp_customize->add_setting( 'elead_pro_theme_options[quality_service_content_category]', array(
	'sanitize_callback' => 'elead_pro_sanitize_single_category'
) );

$wp_customize->add_control( new Elead_Pro_Dropdown_Single_Category_Control( $wp_customize, 'elead_pro_theme_options[quality_service_content_category]', array(
	'label'           => esc_html__( 'Select Category', 'elead-pro' ),
	'description'     => esc_html__( 'Latest posts from selected category will be shown.', 'elead-pro' ),
	'section'         => 'elead_pro_quality_service_section',
	'type'			  => 'dropdown-category',
	'active_callback' => 'elead_pro_quality_service_content_category',
) ) );

// Quality Section content type post setting and control.
$wp_customize->add_setting( 'elead_pro_theme_options[quality_service_content_post]', array(
	'validate_callback' => 'elead_pro_validate_post_id',
	'sanitize_callback' => 'elead_pro_sanitize_post_ids',
) );

$wp_customize->add_control( 'elead_pro_theme_options[quality_service_content_post]', array(
	'active_callback'	=> 'elead_pro_quality_service_content_post',
	'label'             => esc_html__( 'Input Post Ids', 'elead-pro' ),
	'description'       => esc_html__( 'Please input max 9 post ids. ie: 11, 24, 34', 'elead-pro' ),
	'section'           => 'elead_pro_quality_service_section',
	'type'				=> 'text',
) );

for ( $i = 1; $i <= $options['quality_service_count']; $i++ ) {
	// Quality service custom post hr setting and control
	$wp_customize->add_setting( 'elead_pro_theme_options[quality_service_custom_hr_line_'.$i.']', array(
		'sanitize_callback' => 'sanitize_text_field'
	) );

	$wp_customize->add_control( new Elead_Pro_Customize_Horizontal_Line( $wp_customize, 'elead_pro_theme_options[quality_service_custom_hr_line_'.$i.']',
		array(
			'section'         => 'elead_pro_quality_service_section',
			'active_callback' => 'elead_pro_quality_service_content_custom',
			'type'			  => 'hr'
	) ) );

	// Quality service custom note
	$wp_customize->add_setting( 'elead_pro_theme_options[quality_service_custom_note_'.$i.']', array(
		'sanitize_callback'	=> 'sanitize_text_field',
	) );

	$wp_customize->add_control( new Elead_Pro_Note_Control( $wp_customize, 'elead_pro_theme_options[quality_service_custom_note_'.$i.']', array(
		'label'           	=> sprintf( esc_html__( 'Input Custom Value For Quality Service %s ', 'elead-pro' ),$i ),
		'section'         	=> 'elead_pro_quality_service_section',
		'type'            	=> 'description',
		'active_callback' 	=> 'elead_pro_quality_service_content_custom',
	) ) );

	// Quality service custom title setting and control.
	$wp_customize->add_setting( 'elead_pro_theme_options[quality_service_custom_title_'.$i.']', array(
		'sanitize_callback' => 'sanitize_text_field',
		'default'			=> esc_html__( '24/7 Support','elead-pro' ),
	) );

	$wp_customize->add_control( 'elead_pro_theme_options[quality_service_custom_title_'.$i.']', array(
		'active_callback'	=> 'elead_pro_quality_service_content_custom',
		'label'             => sprintf( esc_html__( 'Custom Title %s', 'elead-pro' ),$i ),
		'section'           => 'elead_pro_quality_service_section',
		'type'				=> 'text'
	) );

	// Quality service custom title link setting and control.
	$wp_customize->add_setting( 'elead_pro_theme_options[quality_service_custom_url_'.$i.']', array(
		'sanitize_callback' => 'esc_url_raw',
		'default'			=> esc_html__( '#','elead-pro' ),
	) );

	$wp_customize->add_control( 'elead_pro_theme_options[quality_service_custom_url_'.$i.']', array(
		'active_callback'	=> 'elead_pro_quality_service_content_custom',
		'label'             => sprintf( esc_html__( 'Custom Title Url %s', 'elead-pro' ),$i ),
		'section'           => 'elead_pro_quality_service_section',
		'type'				=> 'url'
	) );

	// Quality service custom excerpt setting and control.
	$wp_customize->add_setting( 'elead_pro_theme_options[quality_service_custom_excerpt_'.$i.']', array(
		'sanitize_callback' => 'wp_kses_post',
		'default'			=> esc_html__( 'Proin efficitur velit et cursus vulputate. Aenean ele mentum sodales libero vitae auctor. Pellentesque tellus nisl, porta eu feugiat et, eleifend ut mi.','elead-pro' ),
	) );

	$wp_customize->add_control( 'elead_pro_theme_options[quality_service_custom_excerpt_'.$i.']', array(
		'active_callback'	=> 'elead_pro_quality_service_content_custom',
		'label'             => sprintf( esc_html__( 'Custom Excerpt %s', 'elead-pro' ),$i ),
		'section'           => 'elead_pro_quality_service_section',
		'type'				=> 'textarea'
	) );

	// Quality service custom icon setting and control.
	$wp_customize->add_setting( 'elead_pro_theme_options[quality_service_custom_icon_'.$i.']', array(
		'sanitize_callback' => 'sanitize_text_field',
		'default'			=> 'fa-phone',
	) );

	$wp_customize->add_control( 'elead_pro_theme_options[quality_service_custom_icon_'.$i.']', array(
		'active_callback'	=> 'elead_pro_quality_service_content_custom',
		'label'             => sprintf( esc_html__( 'Custom Icon %s', 'elead-pro' ),$i ),
		'description'     	=> sprintf( esc_html__( 'Use font awesome icon: Eg: %1$s. %2$s See more here %3$s', 'elead-pro' ), 'fa-users', '<a href="' . esc_url( 'http://fontawesome.io/icons/' ) . '" target="_blank">', '</a>' ),
		'section'           => 'elead_pro_quality_service_section',
		'type'				=> 'text'
	) );
}