<?php
/**
 * Elead Pro Theme Customizer.
 *
 * @package Theme Palace
 * @subpackage Elead Pro
 * @since Elead Pro 1.0
 */

/**
 * Add postMessage support for site title and description for the Theme Customizer.
 *
 * @param WP_Customize_Manager $wp_customize Theme Customizer object.
 */
function elead_pro_customize_register( $wp_customize ) {
	$options = elead_pro_get_theme_options();

	// Load custom control functions.
	require get_template_directory() . '/inc/customizer/custom-controls.php';

	// Load customize active callback functions.
	require get_template_directory() . '/inc/customizer/active-callback.php';

	// Load validation callback functions.
	require get_template_directory() . '/inc/customizer/validation.php';

	// Load partial callback functions.
	require get_template_directory() . '/inc/customizer/partial.php';

	$wp_customize->get_setting( 'blogname' )->transport         = 'postMessage';
	$wp_customize->get_setting( 'blogdescription' )->transport  = 'postMessage';
	$wp_customize->get_setting( 'header_textcolor' )->transport = 'postMessage';

	// Add panel for section options
	$wp_customize->add_panel( 'elead_pro_sections_panel' , array(
	    'title'      => esc_html__( 'Homepage Sections','elead-pro' ),
	    'description'=> esc_html__( 'Homepage Section Options', 'elead-pro' ),
	    'priority'   => 150,
	) );
	
	// headline
	require get_template_directory() . '/inc/customizer/sections/headline.php';

	// Slider
	require get_template_directory() . '/inc/customizer/sections/slider.php';

	// about
	require get_template_directory() . '/inc/customizer/sections/about.php';
	
	// Service
	require get_template_directory() . '/inc/customizer/sections/service.php';
	
	// Courses
	require get_template_directory() . '/inc/customizer/sections/courses.php';

	// Call To Action
	require get_template_directory() . '/inc/customizer/sections/call-to-action.php';

	// Latest News & Events
	require get_template_directory() . '/inc/customizer/sections/latest-news.php';

	// Team
	require get_template_directory() . '/inc/customizer/sections/team.php';

	// Counter
	require get_template_directory() . '/inc/customizer/sections/counter.php';

	// Gallery
	require get_template_directory() . '/inc/customizer/sections/gallery.php';

	// Testimonial
	require get_template_directory() . '/inc/customizer/sections/testimonial.php';

	// subscribe
	require get_template_directory() . '/inc/customizer/sections/subscribe.php';

	// Social
	require get_template_directory() . '/inc/customizer/sections/social.php';

	// Add panel for common theme options
	$wp_customize->add_panel( 'elead_pro_theme_options_panel' , array(
	    'title'      => esc_html__( 'Theme Options','elead-pro' ),
	    'description'=> esc_html__( 'Elead Pro Theme Options.', 'elead-pro' ),
	    'priority'   => 150,
	) );

	// loader
	require get_template_directory() . '/inc/customizer/theme-options/loader.php';

	// typography
	require get_template_directory() . '/inc/customizer/theme-options/typography.php';

	// load layout
	require get_template_directory() . '/inc/customizer/theme-options/layout.php';

	// load static homepage option
	require get_template_directory() . '/inc/customizer/theme-options/homepage-static.php';

	// load breadcrumb option
	require get_template_directory() . '/inc/customizer/theme-options/breadcrumb.php';

	// load pagination option
	require get_template_directory() . '/inc/customizer/theme-options/pagination.php';

	// load footer option
	require get_template_directory() . '/inc/customizer/theme-options/footer.php';

	// load reset option
	require get_template_directory() . '/inc/customizer/theme-options/reset.php';

	// load blog option
	require get_template_directory() . '/inc/customizer/theme-options/blog.php';
	
	// load single option
	require get_template_directory() . '/inc/customizer/theme-options/single.php';

	// load theme color option
	require get_template_directory() . '/inc/customizer/theme-options/theme-color.php';

	// About us template
	require get_template_directory() . '/inc/customizer/custom-template/about-template.php';
	
	// Contact us template
	require get_template_directory() . '/inc/customizer/custom-template/contact-template.php';
	
	// Gallery template
	require get_template_directory() . '/inc/customizer/custom-template/gallery-template.php';

	// Service template
	require get_template_directory() . '/inc/customizer/custom-template/service-template.php';

	// Study abroad template
	require get_template_directory() . '/inc/customizer/custom-template/study-abroad.php';

}
add_action( 'customize_register', 'elead_pro_customize_register' );

/*
 * Load customizer sanitization functions.
 */
require get_template_directory() . '/inc/customizer/sanitize.php';

/**
 * Binds JS handlers to make Theme Customizer preview reload changes asynchronously.
 */
function elead_pro_customize_preview_js() {
	wp_enqueue_script( 'elead_pro_customizer', get_template_directory_uri() . '/assets/js/customizer.min.js', array( 'customize-preview' ), '20151215', true );
}
add_action( 'customize_preview_init', 'elead_pro_customize_preview_js' );


if ( !function_exists( 'elead_pro_reset_options' ) ) :
	/**
	 * Reset all options
	 *
	 * @since Elead Pro 1.0
	 *
	 * @param bool $checked Whether the reset is checked.
	 * @return bool Whether the reset is checked.
	 */
	function elead_pro_reset_options() {
		$options = elead_pro_get_theme_options();
		if ( true === $options['reset_options'] ) {
			// Reset custom theme options.
			set_theme_mod( 'elead_pro_theme_options', array() );
			// Reset custom header and backgrounds.
			remove_theme_mod( 'header_image' );
			remove_theme_mod( 'header_image_data' );
			remove_theme_mod( 'background_image' );
			remove_theme_mod( 'background_color' );
			remove_theme_mod( 'header_textcolor' );
	    }
	  	else {
		    return false;
	  	}
	}
endif;
add_action( 'customize_save_after', 'elead_pro_reset_options' );
