<?php
/**
 * Template part for displaying testimonial post.
 *
 * @link https://codex.wordpress.org/Template_Hierarchy
 *
 * @package Theme Palace
 * @subpackage Elead Pro
 * @since Elead Pro 1.0
 */

$options = elead_pro_get_theme_options();
?>

<section id="testimonial-single">
	<div class="testimonial-single-wrapper">
		<div class="wrapper">
			<article id="post-<?php the_ID(); ?>" <?php post_class(); ?>>
				<figure class="featured-image">
					<?php if ( has_post_thumbnail() ) :
						the_post_thumbnail( 'elead-pro-medium', array( 'alt' => the_title_attribute( 'echo=0' ) ) );
					else :
                		echo '<img src="' . get_template_directory_uri().'/assets/uploads/no-featured-image-500x500.jpg" alt="' . esc_attr( get_the_title() ) . '">';
            		endif; ?>
					<div class="social-icons">
                    	<?php  
							// Testimonial Social Icons
							if ( function_exists( 'tp_testimonial_social' ) )
								tp_testimonial_social();
							?>
                    </div><!--.social-icons-->
				</figure>
				<div class="entry-container">
					<div class="description">
						<img src="<?php echo get_template_directory_uri() . '/assets/uploads/testimonial.png'; ?>">
						<?php the_content(); ?>
					</div><!-- .description -->
					<a href="<?php the_permalink(); ?>" class="readmore">
		                <?php echo ( ! empty( $options['read_more_text'] ) ) ? esc_html( $options['read_more_text'] ) : esc_html_e( 'Read More', 'elead-pro' );  ?>
		            </a>
					<div class="position">
						<h2><?php the_title(); ?></h2>
						<?php  
						// testimonial designation
						if ( function_exists( 'tp_testimonial_designation' ) )
							tp_testimonial_designation();
						?>
					</div><!-- .position -->
					<ul class="star-rating">
						<?php  
						// testimonial ratings
						if ( function_exists( 'tp_testimonial_rating' ) )
							tp_testimonial_rating();
						?>
					</ul><!-- .star-rating -->
				</div><!-- .entry-container -->
			</article>

			<?php  
			if ( true === $options['post_navigation_enable'] ) {
				the_post_navigation();
			}
			?>
		</div><!-- .wrapper -->
	</div><!-- .testimonial-single-wrapper -->

	<div class="testimonial-thumbs">
		<div class="wrapper">
			<?php  
			$testimonial_id = get_the_ID();
			$args = array(
				'post_type'			=> 'tp-testimonial',
				'posts_per_page'	=> -1,
				);
			$posts = get_posts( $args );
			?>
			<ul>
				<?php foreach ( $posts as $post ) : ?>
					<li class="<?php echo ( $testimonial_id == $post->ID ) ? 'active' : ''; ?>" >
						<a href="<?php the_permalink( $post->ID ); ?>" title="<?php echo esc_attr( get_the_title( $post->ID ) ); ?>">
							<?php  
							if ( has_post_thumbnail( $post->ID ) ) :
								$image = wp_get_attachment_image_src( get_post_thumbnail_id( $post->ID ), 'thumbnail' );
							else :
								$image[0] = get_template_directory_uri() . '/assets/uploads/no-featured-image-150x150.jpg';
							endif;
							?>
							<img src="<?php echo esc_url( $image[0] ); ?>" alt="<?php echo esc_attr( $post->post_title ); ?>" >
						</a>
						<div class="position">
                            <h5><a href="<?php the_permalink( $post->ID ); ?>"><?php echo esc_html( get_the_title( $post->ID ) ); ?></a></h5>
                            <?php 
							if ( function_exists( 'tp_testimonial_designation' ) ) :
								tp_testimonial_designation(); 
							endif; ?>
                        </div>
					</li>
				<?php endforeach; 
				wp_reset_postdata(); ?>
			</ul>
		</div><!-- .wrapper -->
	</div><!-- .testimonial-thumbs -->
</section><!-- #testimonial-slider -->
